@@ -834,6 +834,7 @@ gedit_document_output_stream_write (GOutputStream            *stream,
 			g_set_error_literal (error, GEDIT_DOCUMENT_ERROR,
 			                     GEDIT_DOCUMENT_ERROR_ENCODING_AUTO_DETECTION_FAILED,
 			                     _("It is not possible to detect the encoding automatically"));
+
 			return -1;
 		}
 
@@ -865,6 +866,7 @@ gedit_document_output_stream_write (GOutputStream            *stream,
 				}
 
 				g_free (from_charset);
+				g_clear_object (&ostream->priv->charset_conv);
 
 				return -1;
 			}
@@ -1004,9 +1006,15 @@ gedit_document_output_stream_flush (GOutputStream  *stream,
 		gchar *outbuf;
 		gsize outbuf_len;
 
-		convert_text (ostream, NULL, 0, &outbuf, &outbuf_len, error);
-		validate_and_insert (ostream, outbuf, outbuf_len);
-		g_free (outbuf);
+		if (convert_text (ostream, NULL, 0, &outbuf, &outbuf_len, error))
+		{
+			validate_and_insert (ostream, outbuf, outbuf_len);
+			g_free (outbuf);
+		}
+		else
+		{
+			return FALSE;
+		}
 	}
 
 	if (ostream->priv->buflen > 0 && *ostream->priv->buffer != '\r')
