@@ -1383,12 +1383,15 @@ _gedit_document_check_externally_modified (GeditDocument *doc)
 			GTimeVal timeval;
 
 			g_file_info_get_modification_time (info, &timeval);
+
 			g_object_unref (info);
 	
 			return (timeval.tv_sec > doc->priv->mtime.tv_sec) ||
 			       (timeval.tv_sec == doc->priv->mtime.tv_sec && 
 			       timeval.tv_usec > doc->priv->mtime.tv_usec);
 		}
+
+		g_object_unref (info);
 	}
 
 	return FALSE;
@@ -1814,6 +1817,8 @@ gedit_document_save_real (GeditDocument                *doc,
 		               document_signals[SAVED],
 		               0,
 		               error);
+
+		g_error_free (error);
 	}
 	else
 	{
@@ -1908,6 +1913,11 @@ gedit_document_save_as (GeditDocument                *doc,
 		       compression_type,
 		       flags | GEDIT_DOCUMENT_SAVE_IGNORE_MTIME,
 		       error);
+
+	if (error != NULL)
+	{
+		g_error_free (error);
+	}
 }
 
 gboolean
