@@ -250,17 +250,8 @@ gedit_tab_dispose (GObject *object)
 		tab->priv->print_preview = NULL;
 	}
 
-	if (tab->priv->tmp_save_location != NULL)
-	{
-		g_object_unref (tab->priv->tmp_save_location);
-		tab->priv->tmp_save_location = NULL;
-	}
-
-	if (tab->priv->editor != NULL)
-	{
-		g_object_unref (tab->priv->editor);
-		tab->priv->editor = NULL;
-	}
+	g_clear_object (&tab->priv->tmp_save_location);
+	g_clear_object (&tab->priv->editor);
 
 	G_OBJECT_CLASS (gedit_tab_parent_class)->dispose (object);
 }
@@ -950,6 +941,14 @@ remove_tab_idle (GeditTab *tab)
 	return FALSE;
 }
 
+static gboolean
+scroll_to_cursor (GeditTab *tab)
+{
+	gedit_view_scroll_to_cursor (gedit_view_frame_get_view (tab->priv->frame));
+
+	return FALSE;
+}
+
 static void
 document_loaded (GeditDocument *document,
 		 const GError  *error,
@@ -1078,8 +1077,10 @@ document_loaded (GeditDocument *document,
 			gtk_widget_show (emsg);
 		}
 
-		/* Scroll to the cursor when the document is loaded */
-		gedit_view_scroll_to_cursor (gedit_view_frame_get_view (tab->priv->frame));
+		/* Scroll to the cursor when the document is loaded, we need
+		   to do it in an idle as after the document is loaded the
+		   textview is still redrawing and relocating its internals */
+		g_idle_add ((GSourceFunc)scroll_to_cursor, tab);
 
 		/* if the document is readonly we don't care how many times the document
 		   is opened */
