@@ -41,11 +41,11 @@
 #define FILE_REGEX "gedit\\-setup\\-[0-9]+\\.[0-9]+\\.[0-9]+(\\-[0-9]+)?\\.exe"
 #else
 #define GEDIT_URL "http://ftp.acc.umu.se/pub/gnome/binaries/mac/gedit/"
-#define FILE_REGEX "gedit\\-[0-9]+\\.[0-9]+\\.[0-9]+(\\-[0-9]+)?\\.dmg"
+#define FILE_REGEX "gedit\\-[0-9]+\\.[0-9]+\\.[0-9]+(\\-[0-9]+)?(_.*)?\\.dmg"
 #endif
 
 #ifdef OS_OSX
-#include "gedit/osx/gedit-osx.h"
+#include "gedit/gedit-app-osx.h"
 #endif
 
 #define GEDIT_CHECK_UPDATE_PLUGIN_GET_PRIVATE(object) \
@@ -238,7 +238,8 @@ on_response_cb (GtkWidget              *infobar,
 		GError *error = NULL;
 
 #ifdef OS_OSX
-		gedit_osx_show_url (plugin->priv->url);
+		gedit_app_osx_show_url (GEDIT_APP_OSX (gedit_app_get_default ()),
+		                        plugin->priv->url);
 #else
 		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (plugin->priv->window)),
 			      plugin->priv->url,
@@ -467,6 +468,12 @@ parse_page_file (SoupSession            *session,
 		gchar *ignore_version;
 
 		file = get_file (msg->response_body->data, FILE_REGEX);
+
+		if (!file)
+		{
+            return;
+		}
+
 		file_version = parse_file_version (file);
 		ignore_version = get_ignore_version (plugin);
 
